ploneintranet.notifications.adapters package
============================================

Submodules
----------

ploneintranet.notifications.adapters.message_factory module
-----------------------------------------------------------

.. automodule:: ploneintranet.notifications.adapters.message_factory
    :members:
    :undoc-members:
    :show-inheritance:

ploneintranet.notifications.adapters.message_handler module
-----------------------------------------------------------

.. automodule:: ploneintranet.notifications.adapters.message_handler
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ploneintranet.notifications.adapters
    :members:
    :undoc-members:
    :show-inheritance:
